InvocationHandler
Date: 2017-11-20

jep

## Class InvocationHandler

- java.lang.Object
- - jep.InvocationHandler

- All Implemented Interfaces:
    java.lang.reflect.InvocationHandler

      public class InvocationHandler
      extends java.lang.Object
      implements java.lang.reflect.InvocationHandler

  Handle Proxy method calls.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `InvocationHandler(long tstate, long ltarget, Jep jep, boolean functionalInterface)` Creates a new `InvocationHandler` instance.

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `java.lang.Object` | `invoke(java.lang.Object proxy, java.lang.reflect.Method method, java.lang.Object[] args)` Processes a method invocation on a proxy instance and returns the result.

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### InvocationHandler

          public InvocationHandler(long tstate,
                                   long ltarget,
                                   Jep jep,
                                   boolean functionalInterface)
                            throws JepException

      Creates a new `InvocationHandler` instance.
      Parameters:
        `tstate` - the thread state id
        `ltarget` - the python object's id
        `jep` - the jep interpreter
      Throws:
        `JepException` - if an error occurs

  - ### Method Detail

    - #### invoke

          public java.lang.Object invoke(java.lang.Object proxy,
                                         java.lang.reflect.Method method,
                                         java.lang.Object[] args)
                                  throws java.lang.Throwable

      Processes a method invocation on a proxy instance and returns the result. This method will be invoked on an invocation handler when a method is invoked on a proxy instance that it is associated with.
      Specified by:
        `invoke` in interface `java.lang.reflect.InvocationHandler`
      Parameters:
        `proxy` - the proxy instance that the method was invoked on
        `method` - the Method instance corresponding to the interface method invoked on the proxy instance. The declaring class of the Method object will be the interface that the method was declared in, which may be a superinterface of the proxy interface that the proxy class inherits the method through.
        `args` - an array of objects containing the values of the arguments passed in the method invocation on the proxy instance, or null if interface method takes no arguments. Arguments of primitive types are wrapped in instances of the appropriate primitive wrapper class, such as java.lang.Integer or java.lang.Boolean.
      Returns:
        the value to return from the method invocation on the proxy instance. If the declared return type of the interface method is a primitive type, then the value returned by this method must be an instance of the corresponding primitive wrapper class; otherwise, it must be a type assignable to the declared return type. If the value returned by this method is null and the interface method's return type is primitive, then a NullPointerException will be thrown by the method invocation on the proxy instance. If the value returned by this method is otherwise not compatible with the interface method's declared return type as described above, a ClassCastException will be thrown by the method invocation on the proxy instance.
      Throws:
        `java.lang.Throwable` - the exception to throw from the method invocation on the proxy instance. The exception's type must be assignable either to any of the exception types declared in the throws clause of the interface method or to the unchecked exception types java.lang.RuntimeException or java.lang.Error. If a checked exception is thrown by this method that is not assignable to any of the exception types declared in the throws clause of the interface method, then an UndeclaredThrowableException containing the exception that was thrown by this method will be thrown by the method invocation on the proxy instance.